pub fn java_shape_mapping() -> &'static JavaShapeMappingExpand description
The process-wide Java shape mapping, built once on first use.
pub fn java_shape_mapping() -> &'static JavaShapeMappingThe process-wide Java shape mapping, built once on first use.